pub struct BufferAllocatorRef(/* private fields */);Expand description
A shared reference to a buffer allocator.
The static allocator does not need shared ownership, so it is stored without an Arc. This
makes cloning the common static allocator a simple value copy.
Implementations
Sourceimpl BufferAllocatorRef
impl BufferAllocatorRef
Sourcepub fn new(allocator: impl BufferAllocator) -> Self
pub fn new(allocator: impl BufferAllocator) -> Self
Wrap an allocator in a shared reference.
Sourcepub fn statically_allocated() -> Self
pub fn statically_allocated() -> Self
Return a shared reference to the static allocator.
Sourcepub fn static_ref() -> &'static Self
pub fn static_ref() -> &'static Self
Return a borrowed reference to the static allocator.
Sourcepub fn ptr_eq(&self, other: &Self) -> bool
pub fn ptr_eq(&self, other: &Self) -> bool
Returns true if both references point to the same allocator.
Sourcepub fn with_capacity<T>(&self, capacity: usize) -> BufferMut<T>
pub fn with_capacity<T>(&self, capacity: usize) -> BufferMut<T>
Create a mutable buffer with this allocator.
Sourcepub fn with_capacity_aligned<T>(
&self,
capacity: usize,
alignment: Alignment,
) -> BufferMut<T>
pub fn with_capacity_aligned<T>( &self, capacity: usize, alignment: Alignment, ) -> BufferMut<T>
Create an aligned mutable buffer with this allocator.