Module trusted_len

Module trusted_len 

Trusted-length iterator trait and adapters for safe pre-allocation.

Structs

TrustedLenAdapter
An adapter that turns any iterator into a TrustedLen iterator.

Traits

TrustedLen
Trait for all types which have a known upper-bound.
TrustedLenExt
Extension trait for wrapping any iterator in a TrustedLenAdapter.