pub struct Alignment(/* private fields */);Expand description
The alignment of a buffer.
This type is a wrapper around usize that ensures the alignment is a non-zero power of 2.
Implementations
Sourceimpl Alignment
impl Alignment
Sourcepub const DEFAULT_ALIGNMENT: Self
pub const DEFAULT_ALIGNMENT: Self
Default alignment for all buffers.
Chosen to be larger than any SIMD register (e.g. AVX-512’s 64-byte registers) so that buffers can be processed with vectorized loads/stores without alignment fixups, and to match the alignment guarantees of the CUDA allocator (256 bytes) so host buffers can be copied to/from device memory without re-alignment.
Sourcepub const MAX: Alignment
pub const MAX: Alignment
The largest valid alignment: the greatest power of 2 representable in a usize.
Sourcepub const fn of<T>() -> Self
pub const fn of<T>() -> Self
Create an alignment from the alignment of a type T.
Example
use vortex_buffer::Alignment;
assert_eq!(Alignment::new(4), Alignment::of::<i32>());
assert_eq!(Alignment::new(8), Alignment::of::<i64>());
assert_eq!(Alignment::new(16), Alignment::of::<u128>());Sourcepub const fn is_aligned_to(&self, other: Alignment) -> bool
pub const fn is_aligned_to(&self, other: Alignment) -> bool
Check if self alignment is a “larger” than other alignment.
Example
use vortex_buffer::Alignment;
let a = Alignment::new(4);
let b = Alignment::new(2);
assert!(a.is_aligned_to(b));
assert!(!b.is_aligned_to(a));Sourcepub const fn is_offset_aligned(&self, offset: usize) -> bool
pub const fn is_offset_aligned(&self, offset: usize) -> bool
Check if the given byte offset (or length) is a multiple of this alignment.
Example
use vortex_buffer::Alignment;
let a = Alignment::new(4);
assert!(a.is_offset_aligned(8));
assert!(!a.is_offset_aligned(2));Sourcepub fn is_ptr_aligned<T>(&self, ptr: *const T) -> bool
pub fn is_ptr_aligned<T>(&self, ptr: *const T) -> bool
Check if the given pointer is aligned to this alignment.
Sourcepub const fn from_exponent(exponent: u8) -> Self
pub const fn from_exponent(exponent: u8) -> Self